# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class HistoricFailureReasonDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'failure_reason': 'FailureReason',
        'site_name': 'str',
        'details': 'str'
    }

    attribute_map = {
        'failure_reason': 'failure_reason',
        'site_name': 'site_name',
        'details': 'details'
    }

    def __init__(self, failure_reason=None, site_name=None, details=None):  # noqa: E501
        """HistoricFailureReasonDetails - a model defined in Swagger"""  # noqa: E501
        self._failure_reason = None
        self._site_name = None
        self._details = None
        self.discriminator = None
        self.failure_reason = failure_reason
        if site_name is not None:
            self.site_name = site_name
        self.details = details

    @property
    def failure_reason(self):
        """Gets the failure_reason of this HistoricFailureReasonDetails.  # noqa: E501


        :return: The failure_reason of this HistoricFailureReasonDetails.  # noqa: E501
        :rtype: FailureReason
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """Sets the failure_reason of this HistoricFailureReasonDetails.


        :param failure_reason: The failure_reason of this HistoricFailureReasonDetails.  # noqa: E501
        :type: FailureReason
        """
        if failure_reason is None:
            raise ValueError("Invalid value for `failure_reason`, must not be `None`")  # noqa: E501

        self._failure_reason = failure_reason

    @property
    def site_name(self):
        """Gets the site_name of this HistoricFailureReasonDetails.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The site_name of this HistoricFailureReasonDetails.  # noqa: E501
        :rtype: str
        """
        return self._site_name

    @site_name.setter
    def site_name(self, site_name):
        """Sets the site_name of this HistoricFailureReasonDetails.

        Max length 100 characters  # noqa: E501

        :param site_name: The site_name of this HistoricFailureReasonDetails.  # noqa: E501
        :type: str
        """

        self._site_name = site_name

    @property
    def details(self):
        """Gets the details of this HistoricFailureReasonDetails.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The details of this HistoricFailureReasonDetails.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this HistoricFailureReasonDetails.

        Max length 500 characters  # noqa: E501

        :param details: The details of this HistoricFailureReasonDetails.  # noqa: E501
        :type: str
        """
        if details is None:
            raise ValueError("Invalid value for `details`, must not be `None`")  # noqa: E501

        self._details = details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HistoricFailureReasonDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HistoricFailureReasonDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GeographicalareasGeographicalAreaReferenceNumberBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'file': 'str',
        'geographical_area_reference_number': 'str',
        'internal_user_identifier': 'str',
        'internal_user_name': 'str'
    }

    attribute_map = {
        'file': 'file',
        'geographical_area_reference_number': 'geographicalAreaReferenceNumber',
        'internal_user_identifier': 'internalUserIdentifier',
        'internal_user_name': 'internalUserName'
    }

    def __init__(self, file=None, geographical_area_reference_number=None, internal_user_identifier=None, internal_user_name=None):  # noqa: E501
        """GeographicalareasGeographicalAreaReferenceNumberBody - a model defined in Swagger"""  # noqa: E501
        self._file = None
        self._geographical_area_reference_number = None
        self._internal_user_identifier = None
        self._internal_user_name = None
        self.discriminator = None
        if file is not None:
            self.file = file
        if geographical_area_reference_number is not None:
            self.geographical_area_reference_number = geographical_area_reference_number
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name

    @property
    def file(self):
        """Gets the file of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501


        :return: The file of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501
        :rtype: str
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this GeographicalareasGeographicalAreaReferenceNumberBody.


        :param file: The file of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501
        :type: str
        """

        self._file = file

    @property
    def geographical_area_reference_number(self):
        """Gets the geographical_area_reference_number of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501


        :return: The geographical_area_reference_number of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501
        :rtype: str
        """
        return self._geographical_area_reference_number

    @geographical_area_reference_number.setter
    def geographical_area_reference_number(self, geographical_area_reference_number):
        """Sets the geographical_area_reference_number of this GeographicalareasGeographicalAreaReferenceNumberBody.


        :param geographical_area_reference_number: The geographical_area_reference_number of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501
        :type: str
        """

        self._geographical_area_reference_number = geographical_area_reference_number

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501


        :return: The internal_user_identifier of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this GeographicalareasGeographicalAreaReferenceNumberBody.


        :param internal_user_identifier: The internal_user_identifier of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501


        :return: The internal_user_name of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this GeographicalareasGeographicalAreaReferenceNumberBody.


        :param internal_user_name: The internal_user_name of this GeographicalareasGeographicalAreaReferenceNumberBody.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GeographicalareasGeographicalAreaReferenceNumberBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GeographicalareasGeographicalAreaReferenceNumberBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PbiSampleInspectionSummaryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'pbi_sample_inspection_reference_number': 'str',
        'inspection_category': 'InspectionCategoryResponse',
        'inspection_category_string': 'str',
        'sample_expiry_date': 'datetime'
    }

    attribute_map = {
        'pbi_sample_inspection_reference_number': 'pbi_sample_inspection_reference_number',
        'inspection_category': 'inspection_category',
        'inspection_category_string': 'inspection_category_string',
        'sample_expiry_date': 'sample_expiry_date'
    }

    def __init__(self, pbi_sample_inspection_reference_number=None, inspection_category=None, inspection_category_string=None, sample_expiry_date=None):  # noqa: E501
        """PbiSampleInspectionSummaryResponse - a model defined in Swagger"""  # noqa: E501
        self._pbi_sample_inspection_reference_number = None
        self._inspection_category = None
        self._inspection_category_string = None
        self._sample_expiry_date = None
        self.discriminator = None
        self.pbi_sample_inspection_reference_number = pbi_sample_inspection_reference_number
        self.inspection_category = inspection_category
        self.inspection_category_string = inspection_category_string
        self.sample_expiry_date = sample_expiry_date

    @property
    def pbi_sample_inspection_reference_number(self):
        """Gets the pbi_sample_inspection_reference_number of this PbiSampleInspectionSummaryResponse.  # noqa: E501


        :return: The pbi_sample_inspection_reference_number of this PbiSampleInspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._pbi_sample_inspection_reference_number

    @pbi_sample_inspection_reference_number.setter
    def pbi_sample_inspection_reference_number(self, pbi_sample_inspection_reference_number):
        """Sets the pbi_sample_inspection_reference_number of this PbiSampleInspectionSummaryResponse.


        :param pbi_sample_inspection_reference_number: The pbi_sample_inspection_reference_number of this PbiSampleInspectionSummaryResponse.  # noqa: E501
        :type: str
        """
        if pbi_sample_inspection_reference_number is None:
            raise ValueError("Invalid value for `pbi_sample_inspection_reference_number`, must not be `None`")  # noqa: E501

        self._pbi_sample_inspection_reference_number = pbi_sample_inspection_reference_number

    @property
    def inspection_category(self):
        """Gets the inspection_category of this PbiSampleInspectionSummaryResponse.  # noqa: E501


        :return: The inspection_category of this PbiSampleInspectionSummaryResponse.  # noqa: E501
        :rtype: InspectionCategoryResponse
        """
        return self._inspection_category

    @inspection_category.setter
    def inspection_category(self, inspection_category):
        """Sets the inspection_category of this PbiSampleInspectionSummaryResponse.


        :param inspection_category: The inspection_category of this PbiSampleInspectionSummaryResponse.  # noqa: E501
        :type: InspectionCategoryResponse
        """
        if inspection_category is None:
            raise ValueError("Invalid value for `inspection_category`, must not be `None`")  # noqa: E501

        self._inspection_category = inspection_category

    @property
    def inspection_category_string(self):
        """Gets the inspection_category_string of this PbiSampleInspectionSummaryResponse.  # noqa: E501


        :return: The inspection_category_string of this PbiSampleInspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._inspection_category_string

    @inspection_category_string.setter
    def inspection_category_string(self, inspection_category_string):
        """Sets the inspection_category_string of this PbiSampleInspectionSummaryResponse.


        :param inspection_category_string: The inspection_category_string of this PbiSampleInspectionSummaryResponse.  # noqa: E501
        :type: str
        """
        if inspection_category_string is None:
            raise ValueError("Invalid value for `inspection_category_string`, must not be `None`")  # noqa: E501

        self._inspection_category_string = inspection_category_string

    @property
    def sample_expiry_date(self):
        """Gets the sample_expiry_date of this PbiSampleInspectionSummaryResponse.  # noqa: E501


        :return: The sample_expiry_date of this PbiSampleInspectionSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._sample_expiry_date

    @sample_expiry_date.setter
    def sample_expiry_date(self, sample_expiry_date):
        """Sets the sample_expiry_date of this PbiSampleInspectionSummaryResponse.


        :param sample_expiry_date: The sample_expiry_date of this PbiSampleInspectionSummaryResponse.  # noqa: E501
        :type: datetime
        """
        if sample_expiry_date is None:
            raise ValueError("Invalid value for `sample_expiry_date`, must not be `None`")  # noqa: E501

        self._sample_expiry_date = sample_expiry_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PbiSampleInspectionSummaryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PbiSampleInspectionSummaryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Section81SummaryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'section_81_reference_number': 'str',
        'date_created': 'datetime',
        'location_description': 'str',
        'section_81_severity': 'Section81SeverityResponse',
        'section_81_severity_string': 'str',
        'section_81_status': 'Section81StatusResponse',
        'section_81_status_string': 'str',
        'section_81_type': 'Section81TypeResponse',
        'section_81_type_string': 'str'
    }

    attribute_map = {
        'section_81_reference_number': 'section_81_reference_number',
        'date_created': 'date_created',
        'location_description': 'location_description',
        'section_81_severity': 'section_81_severity',
        'section_81_severity_string': 'section_81_severity_string',
        'section_81_status': 'section_81_status',
        'section_81_status_string': 'section_81_status_string',
        'section_81_type': 'section_81_type',
        'section_81_type_string': 'section_81_type_string'
    }

    def __init__(self, section_81_reference_number=None, date_created=None, location_description=None, section_81_severity=None, section_81_severity_string=None, section_81_status=None, section_81_status_string=None, section_81_type=None, section_81_type_string=None):  # noqa: E501
        """Section81SummaryResponse - a model defined in Swagger"""  # noqa: E501
        self._section_81_reference_number = None
        self._date_created = None
        self._location_description = None
        self._section_81_severity = None
        self._section_81_severity_string = None
        self._section_81_status = None
        self._section_81_status_string = None
        self._section_81_type = None
        self._section_81_type_string = None
        self.discriminator = None
        self.section_81_reference_number = section_81_reference_number
        self.date_created = date_created
        self.location_description = location_description
        if section_81_severity is not None:
            self.section_81_severity = section_81_severity
        if section_81_severity_string is not None:
            self.section_81_severity_string = section_81_severity_string
        self.section_81_status = section_81_status
        self.section_81_status_string = section_81_status_string
        if section_81_type is not None:
            self.section_81_type = section_81_type
        if section_81_type_string is not None:
            self.section_81_type_string = section_81_type_string

    @property
    def section_81_reference_number(self):
        """Gets the section_81_reference_number of this Section81SummaryResponse.  # noqa: E501


        :return: The section_81_reference_number of this Section81SummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._section_81_reference_number

    @section_81_reference_number.setter
    def section_81_reference_number(self, section_81_reference_number):
        """Sets the section_81_reference_number of this Section81SummaryResponse.


        :param section_81_reference_number: The section_81_reference_number of this Section81SummaryResponse.  # noqa: E501
        :type: str
        """
        if section_81_reference_number is None:
            raise ValueError("Invalid value for `section_81_reference_number`, must not be `None`")  # noqa: E501

        self._section_81_reference_number = section_81_reference_number

    @property
    def date_created(self):
        """Gets the date_created of this Section81SummaryResponse.  # noqa: E501


        :return: The date_created of this Section81SummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this Section81SummaryResponse.


        :param date_created: The date_created of this Section81SummaryResponse.  # noqa: E501
        :type: datetime
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def location_description(self):
        """Gets the location_description of this Section81SummaryResponse.  # noqa: E501


        :return: The location_description of this Section81SummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._location_description

    @location_description.setter
    def location_description(self, location_description):
        """Sets the location_description of this Section81SummaryResponse.


        :param location_description: The location_description of this Section81SummaryResponse.  # noqa: E501
        :type: str
        """
        if location_description is None:
            raise ValueError("Invalid value for `location_description`, must not be `None`")  # noqa: E501

        self._location_description = location_description

    @property
    def section_81_severity(self):
        """Gets the section_81_severity of this Section81SummaryResponse.  # noqa: E501


        :return: The section_81_severity of this Section81SummaryResponse.  # noqa: E501
        :rtype: Section81SeverityResponse
        """
        return self._section_81_severity

    @section_81_severity.setter
    def section_81_severity(self, section_81_severity):
        """Sets the section_81_severity of this Section81SummaryResponse.


        :param section_81_severity: The section_81_severity of this Section81SummaryResponse.  # noqa: E501
        :type: Section81SeverityResponse
        """

        self._section_81_severity = section_81_severity

    @property
    def section_81_severity_string(self):
        """Gets the section_81_severity_string of this Section81SummaryResponse.  # noqa: E501


        :return: The section_81_severity_string of this Section81SummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._section_81_severity_string

    @section_81_severity_string.setter
    def section_81_severity_string(self, section_81_severity_string):
        """Sets the section_81_severity_string of this Section81SummaryResponse.


        :param section_81_severity_string: The section_81_severity_string of this Section81SummaryResponse.  # noqa: E501
        :type: str
        """

        self._section_81_severity_string = section_81_severity_string

    @property
    def section_81_status(self):
        """Gets the section_81_status of this Section81SummaryResponse.  # noqa: E501


        :return: The section_81_status of this Section81SummaryResponse.  # noqa: E501
        :rtype: Section81StatusResponse
        """
        return self._section_81_status

    @section_81_status.setter
    def section_81_status(self, section_81_status):
        """Sets the section_81_status of this Section81SummaryResponse.


        :param section_81_status: The section_81_status of this Section81SummaryResponse.  # noqa: E501
        :type: Section81StatusResponse
        """
        if section_81_status is None:
            raise ValueError("Invalid value for `section_81_status`, must not be `None`")  # noqa: E501

        self._section_81_status = section_81_status

    @property
    def section_81_status_string(self):
        """Gets the section_81_status_string of this Section81SummaryResponse.  # noqa: E501


        :return: The section_81_status_string of this Section81SummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._section_81_status_string

    @section_81_status_string.setter
    def section_81_status_string(self, section_81_status_string):
        """Sets the section_81_status_string of this Section81SummaryResponse.


        :param section_81_status_string: The section_81_status_string of this Section81SummaryResponse.  # noqa: E501
        :type: str
        """
        if section_81_status_string is None:
            raise ValueError("Invalid value for `section_81_status_string`, must not be `None`")  # noqa: E501

        self._section_81_status_string = section_81_status_string

    @property
    def section_81_type(self):
        """Gets the section_81_type of this Section81SummaryResponse.  # noqa: E501


        :return: The section_81_type of this Section81SummaryResponse.  # noqa: E501
        :rtype: Section81TypeResponse
        """
        return self._section_81_type

    @section_81_type.setter
    def section_81_type(self, section_81_type):
        """Sets the section_81_type of this Section81SummaryResponse.


        :param section_81_type: The section_81_type of this Section81SummaryResponse.  # noqa: E501
        :type: Section81TypeResponse
        """

        self._section_81_type = section_81_type

    @property
    def section_81_type_string(self):
        """Gets the section_81_type_string of this Section81SummaryResponse.  # noqa: E501


        :return: The section_81_type_string of this Section81SummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._section_81_type_string

    @section_81_type_string.setter
    def section_81_type_string(self, section_81_type_string):
        """Sets the section_81_type_string of this Section81SummaryResponse.


        :param section_81_type_string: The section_81_type_string of this Section81SummaryResponse.  # noqa: E501
        :type: str
        """

        self._section_81_type_string = section_81_type_string

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Section81SummaryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Section81SummaryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SiteResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'permit_reference_number': 'str',
        'site_reference_number': 'str',
        'reinstatement_reference_number': 'str',
        'site_description': 'str',
        'depth': 'float',
        'length': 'float',
        'width': 'float',
        'completed_date': 'datetime',
        'end_date': 'datetime',
        'site_status': 'ReinstatementStatusResponse',
        'site_status_string': 'str',
        'reinstatement_type': 'ReinstatementTypeResponse',
        'reinstatement_type_string': 'str',
        'number_of_holes': 'float',
        'is_subsumed': 'bool',
        'subsume_reason': 'str',
        'response_to_remedial_works': 'bool',
        'base_courses_affected': 'bool',
        'location_types': 'list[LocationTypeResponse]',
        'location_types_string': 'list[str]',
        'site_coordinates': 'object',
        'reinstatements': 'list[ReinstatementResponse]'
    }

    attribute_map = {
        'permit_reference_number': 'permit_reference_number',
        'site_reference_number': 'site_reference_number',
        'reinstatement_reference_number': 'reinstatement_reference_number',
        'site_description': 'site_description',
        'depth': 'depth',
        'length': 'length',
        'width': 'width',
        'completed_date': 'completed_date',
        'end_date': 'end_date',
        'site_status': 'site_status',
        'site_status_string': 'site_status_string',
        'reinstatement_type': 'reinstatement_type',
        'reinstatement_type_string': 'reinstatement_type_string',
        'number_of_holes': 'number_of_holes',
        'is_subsumed': 'is_subsumed',
        'subsume_reason': 'subsume_reason',
        'response_to_remedial_works': 'response_to_remedial_works',
        'base_courses_affected': 'base_courses_affected',
        'location_types': 'location_types',
        'location_types_string': 'location_types_string',
        'site_coordinates': 'site_coordinates',
        'reinstatements': 'reinstatements'
    }

    def __init__(self, permit_reference_number=None, site_reference_number=None, reinstatement_reference_number=None, site_description=None, depth=None, length=None, width=None, completed_date=None, end_date=None, site_status=None, site_status_string=None, reinstatement_type=None, reinstatement_type_string=None, number_of_holes=None, is_subsumed=None, subsume_reason=None, response_to_remedial_works=None, base_courses_affected=None, location_types=None, location_types_string=None, site_coordinates=None, reinstatements=None):  # noqa: E501
        """SiteResponse - a model defined in Swagger"""  # noqa: E501
        self._permit_reference_number = None
        self._site_reference_number = None
        self._reinstatement_reference_number = None
        self._site_description = None
        self._depth = None
        self._length = None
        self._width = None
        self._completed_date = None
        self._end_date = None
        self._site_status = None
        self._site_status_string = None
        self._reinstatement_type = None
        self._reinstatement_type_string = None
        self._number_of_holes = None
        self._is_subsumed = None
        self._subsume_reason = None
        self._response_to_remedial_works = None
        self._base_courses_affected = None
        self._location_types = None
        self._location_types_string = None
        self._site_coordinates = None
        self._reinstatements = None
        self.discriminator = None
        if permit_reference_number is not None:
            self.permit_reference_number = permit_reference_number
        self.site_reference_number = site_reference_number
        self.reinstatement_reference_number = reinstatement_reference_number
        self.site_description = site_description
        if depth is not None:
            self.depth = depth
        if length is not None:
            self.length = length
        if width is not None:
            self.width = width
        if completed_date is not None:
            self.completed_date = completed_date
        if end_date is not None:
            self.end_date = end_date
        self.site_status = site_status
        self.site_status_string = site_status_string
        self.reinstatement_type = reinstatement_type
        self.reinstatement_type_string = reinstatement_type_string
        if number_of_holes is not None:
            self.number_of_holes = number_of_holes
        self.is_subsumed = is_subsumed
        if subsume_reason is not None:
            self.subsume_reason = subsume_reason
        if response_to_remedial_works is not None:
            self.response_to_remedial_works = response_to_remedial_works
        if base_courses_affected is not None:
            self.base_courses_affected = base_courses_affected
        self.location_types = location_types
        self.location_types_string = location_types_string
        self.site_coordinates = site_coordinates
        self.reinstatements = reinstatements

    @property
    def permit_reference_number(self):
        """Gets the permit_reference_number of this SiteResponse.  # noqa: E501


        :return: The permit_reference_number of this SiteResponse.  # noqa: E501
        :rtype: str
        """
        return self._permit_reference_number

    @permit_reference_number.setter
    def permit_reference_number(self, permit_reference_number):
        """Sets the permit_reference_number of this SiteResponse.


        :param permit_reference_number: The permit_reference_number of this SiteResponse.  # noqa: E501
        :type: str
        """

        self._permit_reference_number = permit_reference_number

    @property
    def site_reference_number(self):
        """Gets the site_reference_number of this SiteResponse.  # noqa: E501


        :return: The site_reference_number of this SiteResponse.  # noqa: E501
        :rtype: str
        """
        return self._site_reference_number

    @site_reference_number.setter
    def site_reference_number(self, site_reference_number):
        """Sets the site_reference_number of this SiteResponse.


        :param site_reference_number: The site_reference_number of this SiteResponse.  # noqa: E501
        :type: str
        """
        if site_reference_number is None:
            raise ValueError("Invalid value for `site_reference_number`, must not be `None`")  # noqa: E501

        self._site_reference_number = site_reference_number

    @property
    def reinstatement_reference_number(self):
        """Gets the reinstatement_reference_number of this SiteResponse.  # noqa: E501


        :return: The reinstatement_reference_number of this SiteResponse.  # noqa: E501
        :rtype: str
        """
        return self._reinstatement_reference_number

    @reinstatement_reference_number.setter
    def reinstatement_reference_number(self, reinstatement_reference_number):
        """Sets the reinstatement_reference_number of this SiteResponse.


        :param reinstatement_reference_number: The reinstatement_reference_number of this SiteResponse.  # noqa: E501
        :type: str
        """
        if reinstatement_reference_number is None:
            raise ValueError("Invalid value for `reinstatement_reference_number`, must not be `None`")  # noqa: E501

        self._reinstatement_reference_number = reinstatement_reference_number

    @property
    def site_description(self):
        """Gets the site_description of this SiteResponse.  # noqa: E501


        :return: The site_description of this SiteResponse.  # noqa: E501
        :rtype: str
        """
        return self._site_description

    @site_description.setter
    def site_description(self, site_description):
        """Sets the site_description of this SiteResponse.


        :param site_description: The site_description of this SiteResponse.  # noqa: E501
        :type: str
        """
        if site_description is None:
            raise ValueError("Invalid value for `site_description`, must not be `None`")  # noqa: E501

        self._site_description = site_description

    @property
    def depth(self):
        """Gets the depth of this SiteResponse.  # noqa: E501


        :return: The depth of this SiteResponse.  # noqa: E501
        :rtype: float
        """
        return self._depth

    @depth.setter
    def depth(self, depth):
        """Sets the depth of this SiteResponse.


        :param depth: The depth of this SiteResponse.  # noqa: E501
        :type: float
        """

        self._depth = depth

    @property
    def length(self):
        """Gets the length of this SiteResponse.  # noqa: E501


        :return: The length of this SiteResponse.  # noqa: E501
        :rtype: float
        """
        return self._length

    @length.setter
    def length(self, length):
        """Sets the length of this SiteResponse.


        :param length: The length of this SiteResponse.  # noqa: E501
        :type: float
        """

        self._length = length

    @property
    def width(self):
        """Gets the width of this SiteResponse.  # noqa: E501


        :return: The width of this SiteResponse.  # noqa: E501
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this SiteResponse.


        :param width: The width of this SiteResponse.  # noqa: E501
        :type: float
        """

        self._width = width

    @property
    def completed_date(self):
        """Gets the completed_date of this SiteResponse.  # noqa: E501


        :return: The completed_date of this SiteResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._completed_date

    @completed_date.setter
    def completed_date(self, completed_date):
        """Sets the completed_date of this SiteResponse.


        :param completed_date: The completed_date of this SiteResponse.  # noqa: E501
        :type: datetime
        """

        self._completed_date = completed_date

    @property
    def end_date(self):
        """Gets the end_date of this SiteResponse.  # noqa: E501


        :return: The end_date of this SiteResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this SiteResponse.


        :param end_date: The end_date of this SiteResponse.  # noqa: E501
        :type: datetime
        """

        self._end_date = end_date

    @property
    def site_status(self):
        """Gets the site_status of this SiteResponse.  # noqa: E501


        :return: The site_status of this SiteResponse.  # noqa: E501
        :rtype: ReinstatementStatusResponse
        """
        return self._site_status

    @site_status.setter
    def site_status(self, site_status):
        """Sets the site_status of this SiteResponse.


        :param site_status: The site_status of this SiteResponse.  # noqa: E501
        :type: ReinstatementStatusResponse
        """
        if site_status is None:
            raise ValueError("Invalid value for `site_status`, must not be `None`")  # noqa: E501

        self._site_status = site_status

    @property
    def site_status_string(self):
        """Gets the site_status_string of this SiteResponse.  # noqa: E501


        :return: The site_status_string of this SiteResponse.  # noqa: E501
        :rtype: str
        """
        return self._site_status_string

    @site_status_string.setter
    def site_status_string(self, site_status_string):
        """Sets the site_status_string of this SiteResponse.


        :param site_status_string: The site_status_string of this SiteResponse.  # noqa: E501
        :type: str
        """
        if site_status_string is None:
            raise ValueError("Invalid value for `site_status_string`, must not be `None`")  # noqa: E501

        self._site_status_string = site_status_string

    @property
    def reinstatement_type(self):
        """Gets the reinstatement_type of this SiteResponse.  # noqa: E501


        :return: The reinstatement_type of this SiteResponse.  # noqa: E501
        :rtype: ReinstatementTypeResponse
        """
        return self._reinstatement_type

    @reinstatement_type.setter
    def reinstatement_type(self, reinstatement_type):
        """Sets the reinstatement_type of this SiteResponse.


        :param reinstatement_type: The reinstatement_type of this SiteResponse.  # noqa: E501
        :type: ReinstatementTypeResponse
        """
        if reinstatement_type is None:
            raise ValueError("Invalid value for `reinstatement_type`, must not be `None`")  # noqa: E501

        self._reinstatement_type = reinstatement_type

    @property
    def reinstatement_type_string(self):
        """Gets the reinstatement_type_string of this SiteResponse.  # noqa: E501


        :return: The reinstatement_type_string of this SiteResponse.  # noqa: E501
        :rtype: str
        """
        return self._reinstatement_type_string

    @reinstatement_type_string.setter
    def reinstatement_type_string(self, reinstatement_type_string):
        """Sets the reinstatement_type_string of this SiteResponse.


        :param reinstatement_type_string: The reinstatement_type_string of this SiteResponse.  # noqa: E501
        :type: str
        """
        if reinstatement_type_string is None:
            raise ValueError("Invalid value for `reinstatement_type_string`, must not be `None`")  # noqa: E501

        self._reinstatement_type_string = reinstatement_type_string

    @property
    def number_of_holes(self):
        """Gets the number_of_holes of this SiteResponse.  # noqa: E501


        :return: The number_of_holes of this SiteResponse.  # noqa: E501
        :rtype: float
        """
        return self._number_of_holes

    @number_of_holes.setter
    def number_of_holes(self, number_of_holes):
        """Sets the number_of_holes of this SiteResponse.


        :param number_of_holes: The number_of_holes of this SiteResponse.  # noqa: E501
        :type: float
        """

        self._number_of_holes = number_of_holes

    @property
    def is_subsumed(self):
        """Gets the is_subsumed of this SiteResponse.  # noqa: E501


        :return: The is_subsumed of this SiteResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_subsumed

    @is_subsumed.setter
    def is_subsumed(self, is_subsumed):
        """Sets the is_subsumed of this SiteResponse.


        :param is_subsumed: The is_subsumed of this SiteResponse.  # noqa: E501
        :type: bool
        """
        if is_subsumed is None:
            raise ValueError("Invalid value for `is_subsumed`, must not be `None`")  # noqa: E501

        self._is_subsumed = is_subsumed

    @property
    def subsume_reason(self):
        """Gets the subsume_reason of this SiteResponse.  # noqa: E501


        :return: The subsume_reason of this SiteResponse.  # noqa: E501
        :rtype: str
        """
        return self._subsume_reason

    @subsume_reason.setter
    def subsume_reason(self, subsume_reason):
        """Sets the subsume_reason of this SiteResponse.


        :param subsume_reason: The subsume_reason of this SiteResponse.  # noqa: E501
        :type: str
        """

        self._subsume_reason = subsume_reason

    @property
    def response_to_remedial_works(self):
        """Gets the response_to_remedial_works of this SiteResponse.  # noqa: E501


        :return: The response_to_remedial_works of this SiteResponse.  # noqa: E501
        :rtype: bool
        """
        return self._response_to_remedial_works

    @response_to_remedial_works.setter
    def response_to_remedial_works(self, response_to_remedial_works):
        """Sets the response_to_remedial_works of this SiteResponse.


        :param response_to_remedial_works: The response_to_remedial_works of this SiteResponse.  # noqa: E501
        :type: bool
        """

        self._response_to_remedial_works = response_to_remedial_works

    @property
    def base_courses_affected(self):
        """Gets the base_courses_affected of this SiteResponse.  # noqa: E501


        :return: The base_courses_affected of this SiteResponse.  # noqa: E501
        :rtype: bool
        """
        return self._base_courses_affected

    @base_courses_affected.setter
    def base_courses_affected(self, base_courses_affected):
        """Sets the base_courses_affected of this SiteResponse.


        :param base_courses_affected: The base_courses_affected of this SiteResponse.  # noqa: E501
        :type: bool
        """

        self._base_courses_affected = base_courses_affected

    @property
    def location_types(self):
        """Gets the location_types of this SiteResponse.  # noqa: E501


        :return: The location_types of this SiteResponse.  # noqa: E501
        :rtype: list[LocationTypeResponse]
        """
        return self._location_types

    @location_types.setter
    def location_types(self, location_types):
        """Sets the location_types of this SiteResponse.


        :param location_types: The location_types of this SiteResponse.  # noqa: E501
        :type: list[LocationTypeResponse]
        """
        if location_types is None:
            raise ValueError("Invalid value for `location_types`, must not be `None`")  # noqa: E501

        self._location_types = location_types

    @property
    def location_types_string(self):
        """Gets the location_types_string of this SiteResponse.  # noqa: E501


        :return: The location_types_string of this SiteResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._location_types_string

    @location_types_string.setter
    def location_types_string(self, location_types_string):
        """Sets the location_types_string of this SiteResponse.


        :param location_types_string: The location_types_string of this SiteResponse.  # noqa: E501
        :type: list[str]
        """
        if location_types_string is None:
            raise ValueError("Invalid value for `location_types_string`, must not be `None`")  # noqa: E501

        self._location_types_string = location_types_string

    @property
    def site_coordinates(self):
        """Gets the site_coordinates of this SiteResponse.  # noqa: E501


        :return: The site_coordinates of this SiteResponse.  # noqa: E501
        :rtype: object
        """
        return self._site_coordinates

    @site_coordinates.setter
    def site_coordinates(self, site_coordinates):
        """Sets the site_coordinates of this SiteResponse.


        :param site_coordinates: The site_coordinates of this SiteResponse.  # noqa: E501
        :type: object
        """
        if site_coordinates is None:
            raise ValueError("Invalid value for `site_coordinates`, must not be `None`")  # noqa: E501

        self._site_coordinates = site_coordinates

    @property
    def reinstatements(self):
        """Gets the reinstatements of this SiteResponse.  # noqa: E501


        :return: The reinstatements of this SiteResponse.  # noqa: E501
        :rtype: list[ReinstatementResponse]
        """
        return self._reinstatements

    @reinstatements.setter
    def reinstatements(self, reinstatements):
        """Sets the reinstatements of this SiteResponse.


        :param reinstatements: The reinstatements of this SiteResponse.  # noqa: E501
        :type: list[ReinstatementResponse]
        """
        if reinstatements is None:
            raise ValueError("Invalid value for `reinstatements`, must not be `None`")  # noqa: E501

        self._reinstatements = reinstatements

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SiteResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SiteResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WorkCategoryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'work_category': 'WorkCategoryResponseEnum',
        'work_category_string': 'str',
        'duration': 'DurationCalculationResponse',
        'validity_period_end_date': 'datetime',
        'is_early_start': 'bool'
    }

    attribute_map = {
        'work_category': 'work_category',
        'work_category_string': 'work_category_string',
        'duration': 'duration',
        'validity_period_end_date': 'validity_period_end_date',
        'is_early_start': 'is_early_start'
    }

    def __init__(self, work_category=None, work_category_string=None, duration=None, validity_period_end_date=None, is_early_start=None):  # noqa: E501
        """WorkCategoryResponse - a model defined in Swagger"""  # noqa: E501
        self._work_category = None
        self._work_category_string = None
        self._duration = None
        self._validity_period_end_date = None
        self._is_early_start = None
        self.discriminator = None
        self.work_category = work_category
        self.work_category_string = work_category_string
        self.duration = duration
        self.validity_period_end_date = validity_period_end_date
        self.is_early_start = is_early_start

    @property
    def work_category(self):
        """Gets the work_category of this WorkCategoryResponse.  # noqa: E501


        :return: The work_category of this WorkCategoryResponse.  # noqa: E501
        :rtype: WorkCategoryResponseEnum
        """
        return self._work_category

    @work_category.setter
    def work_category(self, work_category):
        """Sets the work_category of this WorkCategoryResponse.


        :param work_category: The work_category of this WorkCategoryResponse.  # noqa: E501
        :type: WorkCategoryResponseEnum
        """
        if work_category is None:
            raise ValueError("Invalid value for `work_category`, must not be `None`")  # noqa: E501

        self._work_category = work_category

    @property
    def work_category_string(self):
        """Gets the work_category_string of this WorkCategoryResponse.  # noqa: E501


        :return: The work_category_string of this WorkCategoryResponse.  # noqa: E501
        :rtype: str
        """
        return self._work_category_string

    @work_category_string.setter
    def work_category_string(self, work_category_string):
        """Sets the work_category_string of this WorkCategoryResponse.


        :param work_category_string: The work_category_string of this WorkCategoryResponse.  # noqa: E501
        :type: str
        """
        if work_category_string is None:
            raise ValueError("Invalid value for `work_category_string`, must not be `None`")  # noqa: E501

        self._work_category_string = work_category_string

    @property
    def duration(self):
        """Gets the duration of this WorkCategoryResponse.  # noqa: E501


        :return: The duration of this WorkCategoryResponse.  # noqa: E501
        :rtype: DurationCalculationResponse
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this WorkCategoryResponse.


        :param duration: The duration of this WorkCategoryResponse.  # noqa: E501
        :type: DurationCalculationResponse
        """
        if duration is None:
            raise ValueError("Invalid value for `duration`, must not be `None`")  # noqa: E501

        self._duration = duration

    @property
    def validity_period_end_date(self):
        """Gets the validity_period_end_date of this WorkCategoryResponse.  # noqa: E501


        :return: The validity_period_end_date of this WorkCategoryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._validity_period_end_date

    @validity_period_end_date.setter
    def validity_period_end_date(self, validity_period_end_date):
        """Sets the validity_period_end_date of this WorkCategoryResponse.


        :param validity_period_end_date: The validity_period_end_date of this WorkCategoryResponse.  # noqa: E501
        :type: datetime
        """
        if validity_period_end_date is None:
            raise ValueError("Invalid value for `validity_period_end_date`, must not be `None`")  # noqa: E501

        self._validity_period_end_date = validity_period_end_date

    @property
    def is_early_start(self):
        """Gets the is_early_start of this WorkCategoryResponse.  # noqa: E501


        :return: The is_early_start of this WorkCategoryResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_early_start

    @is_early_start.setter
    def is_early_start(self, is_early_start):
        """Sets the is_early_start of this WorkCategoryResponse.


        :param is_early_start: The is_early_start of this WorkCategoryResponse.  # noqa: E501
        :type: bool
        """
        if is_early_start is None:
            raise ValueError("Invalid value for `is_early_start`, must not be `None`")  # noqa: E501

        self._is_early_start = is_early_start

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkCategoryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkCategoryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Section58Response(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'section_58_reference_number': 'str',
        'usrn': 'float',
        'street_name': 'str',
        'town': 'str',
        'area_name': 'str',
        'section_58_coordinates': 'object',
        'contact_organisation': 'str',
        'contact_details': 'str',
        'start_date': 'datetime',
        'end_date': 'datetime',
        'location_types': 'list[LocationTypeResponse]',
        'location_types_string': 'list[str]',
        'additional_information': 'str',
        'highway_authority_swa_code': 'str',
        'status_change_date': 'datetime',
        'section_58_status': 'Section58StatusResponse',
        'section_58_status_string': 'str',
        'restriction_duration': 'Section58DurationResponse',
        'restriction_duration_string': 'str',
        'restriction_extent': 'Section58ExtentResponse',
        'restriction_extent_string': 'str',
        'cancellation_reason': 'str'
    }

    attribute_map = {
        'section_58_reference_number': 'section_58_reference_number',
        'usrn': 'usrn',
        'street_name': 'street_name',
        'town': 'town',
        'area_name': 'area_name',
        'section_58_coordinates': 'section_58_coordinates',
        'contact_organisation': 'contact_organisation',
        'contact_details': 'contact_details',
        'start_date': 'start_date',
        'end_date': 'end_date',
        'location_types': 'location_types',
        'location_types_string': 'location_types_string',
        'additional_information': 'additional_information',
        'highway_authority_swa_code': 'highway_authority_swa_code',
        'status_change_date': 'status_change_date',
        'section_58_status': 'section_58_status',
        'section_58_status_string': 'section_58_status_string',
        'restriction_duration': 'restriction_duration',
        'restriction_duration_string': 'restriction_duration_string',
        'restriction_extent': 'restriction_extent',
        'restriction_extent_string': 'restriction_extent_string',
        'cancellation_reason': 'cancellation_reason'
    }

    def __init__(self, section_58_reference_number=None, usrn=None, street_name=None, town=None, area_name=None, section_58_coordinates=None, contact_organisation=None, contact_details=None, start_date=None, end_date=None, location_types=None, location_types_string=None, additional_information=None, highway_authority_swa_code=None, status_change_date=None, section_58_status=None, section_58_status_string=None, restriction_duration=None, restriction_duration_string=None, restriction_extent=None, restriction_extent_string=None, cancellation_reason=None):  # noqa: E501
        """Section58Response - a model defined in Swagger"""  # noqa: E501
        self._section_58_reference_number = None
        self._usrn = None
        self._street_name = None
        self._town = None
        self._area_name = None
        self._section_58_coordinates = None
        self._contact_organisation = None
        self._contact_details = None
        self._start_date = None
        self._end_date = None
        self._location_types = None
        self._location_types_string = None
        self._additional_information = None
        self._highway_authority_swa_code = None
        self._status_change_date = None
        self._section_58_status = None
        self._section_58_status_string = None
        self._restriction_duration = None
        self._restriction_duration_string = None
        self._restriction_extent = None
        self._restriction_extent_string = None
        self._cancellation_reason = None
        self.discriminator = None
        self.section_58_reference_number = section_58_reference_number
        self.usrn = usrn
        self.street_name = street_name
        if town is not None:
            self.town = town
        if area_name is not None:
            self.area_name = area_name
        self.section_58_coordinates = section_58_coordinates
        if contact_organisation is not None:
            self.contact_organisation = contact_organisation
        if contact_details is not None:
            self.contact_details = contact_details
        self.start_date = start_date
        self.end_date = end_date
        self.location_types = location_types
        self.location_types_string = location_types_string
        if additional_information is not None:
            self.additional_information = additional_information
        self.highway_authority_swa_code = highway_authority_swa_code
        self.status_change_date = status_change_date
        self.section_58_status = section_58_status
        self.section_58_status_string = section_58_status_string
        self.restriction_duration = restriction_duration
        self.restriction_duration_string = restriction_duration_string
        self.restriction_extent = restriction_extent
        self.restriction_extent_string = restriction_extent_string
        if cancellation_reason is not None:
            self.cancellation_reason = cancellation_reason

    @property
    def section_58_reference_number(self):
        """Gets the section_58_reference_number of this Section58Response.  # noqa: E501


        :return: The section_58_reference_number of this Section58Response.  # noqa: E501
        :rtype: str
        """
        return self._section_58_reference_number

    @section_58_reference_number.setter
    def section_58_reference_number(self, section_58_reference_number):
        """Sets the section_58_reference_number of this Section58Response.


        :param section_58_reference_number: The section_58_reference_number of this Section58Response.  # noqa: E501
        :type: str
        """
        if section_58_reference_number is None:
            raise ValueError("Invalid value for `section_58_reference_number`, must not be `None`")  # noqa: E501

        self._section_58_reference_number = section_58_reference_number

    @property
    def usrn(self):
        """Gets the usrn of this Section58Response.  # noqa: E501


        :return: The usrn of this Section58Response.  # noqa: E501
        :rtype: float
        """
        return self._usrn

    @usrn.setter
    def usrn(self, usrn):
        """Sets the usrn of this Section58Response.


        :param usrn: The usrn of this Section58Response.  # noqa: E501
        :type: float
        """
        if usrn is None:
            raise ValueError("Invalid value for `usrn`, must not be `None`")  # noqa: E501

        self._usrn = usrn

    @property
    def street_name(self):
        """Gets the street_name of this Section58Response.  # noqa: E501


        :return: The street_name of this Section58Response.  # noqa: E501
        :rtype: str
        """
        return self._street_name

    @street_name.setter
    def street_name(self, street_name):
        """Sets the street_name of this Section58Response.


        :param street_name: The street_name of this Section58Response.  # noqa: E501
        :type: str
        """
        if street_name is None:
            raise ValueError("Invalid value for `street_name`, must not be `None`")  # noqa: E501

        self._street_name = street_name

    @property
    def town(self):
        """Gets the town of this Section58Response.  # noqa: E501


        :return: The town of this Section58Response.  # noqa: E501
        :rtype: str
        """
        return self._town

    @town.setter
    def town(self, town):
        """Sets the town of this Section58Response.


        :param town: The town of this Section58Response.  # noqa: E501
        :type: str
        """

        self._town = town

    @property
    def area_name(self):
        """Gets the area_name of this Section58Response.  # noqa: E501


        :return: The area_name of this Section58Response.  # noqa: E501
        :rtype: str
        """
        return self._area_name

    @area_name.setter
    def area_name(self, area_name):
        """Sets the area_name of this Section58Response.


        :param area_name: The area_name of this Section58Response.  # noqa: E501
        :type: str
        """

        self._area_name = area_name

    @property
    def section_58_coordinates(self):
        """Gets the section_58_coordinates of this Section58Response.  # noqa: E501


        :return: The section_58_coordinates of this Section58Response.  # noqa: E501
        :rtype: object
        """
        return self._section_58_coordinates

    @section_58_coordinates.setter
    def section_58_coordinates(self, section_58_coordinates):
        """Sets the section_58_coordinates of this Section58Response.


        :param section_58_coordinates: The section_58_coordinates of this Section58Response.  # noqa: E501
        :type: object
        """
        if section_58_coordinates is None:
            raise ValueError("Invalid value for `section_58_coordinates`, must not be `None`")  # noqa: E501

        self._section_58_coordinates = section_58_coordinates

    @property
    def contact_organisation(self):
        """Gets the contact_organisation of this Section58Response.  # noqa: E501


        :return: The contact_organisation of this Section58Response.  # noqa: E501
        :rtype: str
        """
        return self._contact_organisation

    @contact_organisation.setter
    def contact_organisation(self, contact_organisation):
        """Sets the contact_organisation of this Section58Response.


        :param contact_organisation: The contact_organisation of this Section58Response.  # noqa: E501
        :type: str
        """

        self._contact_organisation = contact_organisation

    @property
    def contact_details(self):
        """Gets the contact_details of this Section58Response.  # noqa: E501


        :return: The contact_details of this Section58Response.  # noqa: E501
        :rtype: str
        """
        return self._contact_details

    @contact_details.setter
    def contact_details(self, contact_details):
        """Sets the contact_details of this Section58Response.


        :param contact_details: The contact_details of this Section58Response.  # noqa: E501
        :type: str
        """

        self._contact_details = contact_details

    @property
    def start_date(self):
        """Gets the start_date of this Section58Response.  # noqa: E501


        :return: The start_date of this Section58Response.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Section58Response.


        :param start_date: The start_date of this Section58Response.  # noqa: E501
        :type: datetime
        """
        if start_date is None:
            raise ValueError("Invalid value for `start_date`, must not be `None`")  # noqa: E501

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this Section58Response.  # noqa: E501


        :return: The end_date of this Section58Response.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this Section58Response.


        :param end_date: The end_date of this Section58Response.  # noqa: E501
        :type: datetime
        """
        if end_date is None:
            raise ValueError("Invalid value for `end_date`, must not be `None`")  # noqa: E501

        self._end_date = end_date

    @property
    def location_types(self):
        """Gets the location_types of this Section58Response.  # noqa: E501


        :return: The location_types of this Section58Response.  # noqa: E501
        :rtype: list[LocationTypeResponse]
        """
        return self._location_types

    @location_types.setter
    def location_types(self, location_types):
        """Sets the location_types of this Section58Response.


        :param location_types: The location_types of this Section58Response.  # noqa: E501
        :type: list[LocationTypeResponse]
        """
        if location_types is None:
            raise ValueError("Invalid value for `location_types`, must not be `None`")  # noqa: E501

        self._location_types = location_types

    @property
    def location_types_string(self):
        """Gets the location_types_string of this Section58Response.  # noqa: E501


        :return: The location_types_string of this Section58Response.  # noqa: E501
        :rtype: list[str]
        """
        return self._location_types_string

    @location_types_string.setter
    def location_types_string(self, location_types_string):
        """Sets the location_types_string of this Section58Response.


        :param location_types_string: The location_types_string of this Section58Response.  # noqa: E501
        :type: list[str]
        """
        if location_types_string is None:
            raise ValueError("Invalid value for `location_types_string`, must not be `None`")  # noqa: E501

        self._location_types_string = location_types_string

    @property
    def additional_information(self):
        """Gets the additional_information of this Section58Response.  # noqa: E501


        :return: The additional_information of this Section58Response.  # noqa: E501
        :rtype: str
        """
        return self._additional_information

    @additional_information.setter
    def additional_information(self, additional_information):
        """Sets the additional_information of this Section58Response.


        :param additional_information: The additional_information of this Section58Response.  # noqa: E501
        :type: str
        """

        self._additional_information = additional_information

    @property
    def highway_authority_swa_code(self):
        """Gets the highway_authority_swa_code of this Section58Response.  # noqa: E501


        :return: The highway_authority_swa_code of this Section58Response.  # noqa: E501
        :rtype: str
        """
        return self._highway_authority_swa_code

    @highway_authority_swa_code.setter
    def highway_authority_swa_code(self, highway_authority_swa_code):
        """Sets the highway_authority_swa_code of this Section58Response.


        :param highway_authority_swa_code: The highway_authority_swa_code of this Section58Response.  # noqa: E501
        :type: str
        """
        if highway_authority_swa_code is None:
            raise ValueError("Invalid value for `highway_authority_swa_code`, must not be `None`")  # noqa: E501

        self._highway_authority_swa_code = highway_authority_swa_code

    @property
    def status_change_date(self):
        """Gets the status_change_date of this Section58Response.  # noqa: E501


        :return: The status_change_date of this Section58Response.  # noqa: E501
        :rtype: datetime
        """
        return self._status_change_date

    @status_change_date.setter
    def status_change_date(self, status_change_date):
        """Sets the status_change_date of this Section58Response.


        :param status_change_date: The status_change_date of this Section58Response.  # noqa: E501
        :type: datetime
        """
        if status_change_date is None:
            raise ValueError("Invalid value for `status_change_date`, must not be `None`")  # noqa: E501

        self._status_change_date = status_change_date

    @property
    def section_58_status(self):
        """Gets the section_58_status of this Section58Response.  # noqa: E501


        :return: The section_58_status of this Section58Response.  # noqa: E501
        :rtype: Section58StatusResponse
        """
        return self._section_58_status

    @section_58_status.setter
    def section_58_status(self, section_58_status):
        """Sets the section_58_status of this Section58Response.


        :param section_58_status: The section_58_status of this Section58Response.  # noqa: E501
        :type: Section58StatusResponse
        """
        if section_58_status is None:
            raise ValueError("Invalid value for `section_58_status`, must not be `None`")  # noqa: E501

        self._section_58_status = section_58_status

    @property
    def section_58_status_string(self):
        """Gets the section_58_status_string of this Section58Response.  # noqa: E501


        :return: The section_58_status_string of this Section58Response.  # noqa: E501
        :rtype: str
        """
        return self._section_58_status_string

    @section_58_status_string.setter
    def section_58_status_string(self, section_58_status_string):
        """Sets the section_58_status_string of this Section58Response.


        :param section_58_status_string: The section_58_status_string of this Section58Response.  # noqa: E501
        :type: str
        """
        if section_58_status_string is None:
            raise ValueError("Invalid value for `section_58_status_string`, must not be `None`")  # noqa: E501

        self._section_58_status_string = section_58_status_string

    @property
    def restriction_duration(self):
        """Gets the restriction_duration of this Section58Response.  # noqa: E501


        :return: The restriction_duration of this Section58Response.  # noqa: E501
        :rtype: Section58DurationResponse
        """
        return self._restriction_duration

    @restriction_duration.setter
    def restriction_duration(self, restriction_duration):
        """Sets the restriction_duration of this Section58Response.


        :param restriction_duration: The restriction_duration of this Section58Response.  # noqa: E501
        :type: Section58DurationResponse
        """
        if restriction_duration is None:
            raise ValueError("Invalid value for `restriction_duration`, must not be `None`")  # noqa: E501

        self._restriction_duration = restriction_duration

    @property
    def restriction_duration_string(self):
        """Gets the restriction_duration_string of this Section58Response.  # noqa: E501


        :return: The restriction_duration_string of this Section58Response.  # noqa: E501
        :rtype: str
        """
        return self._restriction_duration_string

    @restriction_duration_string.setter
    def restriction_duration_string(self, restriction_duration_string):
        """Sets the restriction_duration_string of this Section58Response.


        :param restriction_duration_string: The restriction_duration_string of this Section58Response.  # noqa: E501
        :type: str
        """
        if restriction_duration_string is None:
            raise ValueError("Invalid value for `restriction_duration_string`, must not be `None`")  # noqa: E501

        self._restriction_duration_string = restriction_duration_string

    @property
    def restriction_extent(self):
        """Gets the restriction_extent of this Section58Response.  # noqa: E501


        :return: The restriction_extent of this Section58Response.  # noqa: E501
        :rtype: Section58ExtentResponse
        """
        return self._restriction_extent

    @restriction_extent.setter
    def restriction_extent(self, restriction_extent):
        """Sets the restriction_extent of this Section58Response.


        :param restriction_extent: The restriction_extent of this Section58Response.  # noqa: E501
        :type: Section58ExtentResponse
        """
        if restriction_extent is None:
            raise ValueError("Invalid value for `restriction_extent`, must not be `None`")  # noqa: E501

        self._restriction_extent = restriction_extent

    @property
    def restriction_extent_string(self):
        """Gets the restriction_extent_string of this Section58Response.  # noqa: E501


        :return: The restriction_extent_string of this Section58Response.  # noqa: E501
        :rtype: str
        """
        return self._restriction_extent_string

    @restriction_extent_string.setter
    def restriction_extent_string(self, restriction_extent_string):
        """Sets the restriction_extent_string of this Section58Response.


        :param restriction_extent_string: The restriction_extent_string of this Section58Response.  # noqa: E501
        :type: str
        """
        if restriction_extent_string is None:
            raise ValueError("Invalid value for `restriction_extent_string`, must not be `None`")  # noqa: E501

        self._restriction_extent_string = restriction_extent_string

    @property
    def cancellation_reason(self):
        """Gets the cancellation_reason of this Section58Response.  # noqa: E501


        :return: The cancellation_reason of this Section58Response.  # noqa: E501
        :rtype: str
        """
        return self._cancellation_reason

    @cancellation_reason.setter
    def cancellation_reason(self, cancellation_reason):
        """Sets the cancellation_reason of this Section58Response.


        :param cancellation_reason: The cancellation_reason of this Section58Response.  # noqa: E501
        :type: str
        """

        self._cancellation_reason = cancellation_reason

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Section58Response, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Section58Response):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CreateAncillaryInfoRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_user_identifier': 'str',
        'internal_user_name': 'str',
        'location_description': 'str',
        'ancillary_info_description': 'str',
        'ancillary_info_coordinates': 'list[object]',
        'usrns': 'list[float]',
        'ancillary_info_type': 'AncillaryInfoType'
    }

    attribute_map = {
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name',
        'location_description': 'location_description',
        'ancillary_info_description': 'ancillary_info_description',
        'ancillary_info_coordinates': 'ancillary_info_coordinates',
        'usrns': 'usrns',
        'ancillary_info_type': 'ancillary_info_type'
    }

    def __init__(self, internal_user_identifier=None, internal_user_name=None, location_description=None, ancillary_info_description=None, ancillary_info_coordinates=None, usrns=None, ancillary_info_type=None):  # noqa: E501
        """CreateAncillaryInfoRequest - a model defined in Swagger"""  # noqa: E501
        self._internal_user_identifier = None
        self._internal_user_name = None
        self._location_description = None
        self._ancillary_info_description = None
        self._ancillary_info_coordinates = None
        self._usrns = None
        self._ancillary_info_type = None
        self.discriminator = None
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name
        if location_description is not None:
            self.location_description = location_description
        self.ancillary_info_description = ancillary_info_description
        self.ancillary_info_coordinates = ancillary_info_coordinates
        self.usrns = usrns
        self.ancillary_info_type = ancillary_info_type

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this CreateAncillaryInfoRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_identifier of this CreateAncillaryInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this CreateAncillaryInfoRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_identifier: The internal_user_identifier of this CreateAncillaryInfoRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this CreateAncillaryInfoRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_name of this CreateAncillaryInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this CreateAncillaryInfoRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_name: The internal_user_name of this CreateAncillaryInfoRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    @property
    def location_description(self):
        """Gets the location_description of this CreateAncillaryInfoRequest.  # noqa: E501

        Max length 500 characters Must be provided if ancillary_info_type is anything other than portable_traffic_signals_or_other_traffic_controls  # noqa: E501

        :return: The location_description of this CreateAncillaryInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._location_description

    @location_description.setter
    def location_description(self, location_description):
        """Sets the location_description of this CreateAncillaryInfoRequest.

        Max length 500 characters Must be provided if ancillary_info_type is anything other than portable_traffic_signals_or_other_traffic_controls  # noqa: E501

        :param location_description: The location_description of this CreateAncillaryInfoRequest.  # noqa: E501
        :type: str
        """

        self._location_description = location_description

    @property
    def ancillary_info_description(self):
        """Gets the ancillary_info_description of this CreateAncillaryInfoRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The ancillary_info_description of this CreateAncillaryInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._ancillary_info_description

    @ancillary_info_description.setter
    def ancillary_info_description(self, ancillary_info_description):
        """Sets the ancillary_info_description of this CreateAncillaryInfoRequest.

        Max length 500 characters  # noqa: E501

        :param ancillary_info_description: The ancillary_info_description of this CreateAncillaryInfoRequest.  # noqa: E501
        :type: str
        """
        if ancillary_info_description is None:
            raise ValueError("Invalid value for `ancillary_info_description`, must not be `None`")  # noqa: E501

        self._ancillary_info_description = ancillary_info_description

    @property
    def ancillary_info_coordinates(self):
        """Gets the ancillary_info_coordinates of this CreateAncillaryInfoRequest.  # noqa: E501

        Array values must be unique Each point must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point Max length of 10  # noqa: E501

        :return: The ancillary_info_coordinates of this CreateAncillaryInfoRequest.  # noqa: E501
        :rtype: list[object]
        """
        return self._ancillary_info_coordinates

    @ancillary_info_coordinates.setter
    def ancillary_info_coordinates(self, ancillary_info_coordinates):
        """Sets the ancillary_info_coordinates of this CreateAncillaryInfoRequest.

        Array values must be unique Each point must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point Max length of 10  # noqa: E501

        :param ancillary_info_coordinates: The ancillary_info_coordinates of this CreateAncillaryInfoRequest.  # noqa: E501
        :type: list[object]
        """
        if ancillary_info_coordinates is None:
            raise ValueError("Invalid value for `ancillary_info_coordinates`, must not be `None`")  # noqa: E501

        self._ancillary_info_coordinates = ancillary_info_coordinates

    @property
    def usrns(self):
        """Gets the usrns of this CreateAncillaryInfoRequest.  # noqa: E501

        Array values must be unique Is whole number between 1000001 and 99999999 inclusive See business rules section 1.4 - USRN Max length of 25  # noqa: E501

        :return: The usrns of this CreateAncillaryInfoRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._usrns

    @usrns.setter
    def usrns(self, usrns):
        """Sets the usrns of this CreateAncillaryInfoRequest.

        Array values must be unique Is whole number between 1000001 and 99999999 inclusive See business rules section 1.4 - USRN Max length of 25  # noqa: E501

        :param usrns: The usrns of this CreateAncillaryInfoRequest.  # noqa: E501
        :type: list[float]
        """
        if usrns is None:
            raise ValueError("Invalid value for `usrns`, must not be `None`")  # noqa: E501

        self._usrns = usrns

    @property
    def ancillary_info_type(self):
        """Gets the ancillary_info_type of this CreateAncillaryInfoRequest.  # noqa: E501


        :return: The ancillary_info_type of this CreateAncillaryInfoRequest.  # noqa: E501
        :rtype: AncillaryInfoType
        """
        return self._ancillary_info_type

    @ancillary_info_type.setter
    def ancillary_info_type(self, ancillary_info_type):
        """Sets the ancillary_info_type of this CreateAncillaryInfoRequest.


        :param ancillary_info_type: The ancillary_info_type of this CreateAncillaryInfoRequest.  # noqa: E501
        :type: AncillaryInfoType
        """
        if ancillary_info_type is None:
            raise ValueError("Invalid value for `ancillary_info_type`, must not be `None`")  # noqa: E501

        self._ancillary_info_type = ancillary_info_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateAncillaryInfoRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateAncillaryInfoRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AncillaryInfoResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ancillary_info_reference_number': 'str',
        'location_description': 'str',
        'ancillary_info_type': 'AncillaryInfoTypeResponse',
        'ancillary_info_status': 'AncillaryInfoStatusResponse',
        'ancillary_info_type_string': 'str',
        'ancillary_info_status_string': 'str',
        'date_created': 'datetime',
        'date_removed': 'datetime',
        'ancillary_info_description': 'str',
        'ancillary_info_removal_reason': 'str',
        'ancillary_info_coordinates': 'list[object]',
        'usrns': 'list[float]'
    }

    attribute_map = {
        'ancillary_info_reference_number': 'ancillary_info_reference_number',
        'location_description': 'location_description',
        'ancillary_info_type': 'ancillary_info_type',
        'ancillary_info_status': 'ancillary_info_status',
        'ancillary_info_type_string': 'ancillary_info_type_string',
        'ancillary_info_status_string': 'ancillary_info_status_string',
        'date_created': 'date_created',
        'date_removed': 'date_removed',
        'ancillary_info_description': 'ancillary_info_description',
        'ancillary_info_removal_reason': 'ancillary_info_removal_reason',
        'ancillary_info_coordinates': 'ancillary_info_coordinates',
        'usrns': 'usrns'
    }

    def __init__(self, ancillary_info_reference_number=None, location_description=None, ancillary_info_type=None, ancillary_info_status=None, ancillary_info_type_string=None, ancillary_info_status_string=None, date_created=None, date_removed=None, ancillary_info_description=None, ancillary_info_removal_reason=None, ancillary_info_coordinates=None, usrns=None):  # noqa: E501
        """AncillaryInfoResponse - a model defined in Swagger"""  # noqa: E501
        self._ancillary_info_reference_number = None
        self._location_description = None
        self._ancillary_info_type = None
        self._ancillary_info_status = None
        self._ancillary_info_type_string = None
        self._ancillary_info_status_string = None
        self._date_created = None
        self._date_removed = None
        self._ancillary_info_description = None
        self._ancillary_info_removal_reason = None
        self._ancillary_info_coordinates = None
        self._usrns = None
        self.discriminator = None
        self.ancillary_info_reference_number = ancillary_info_reference_number
        if location_description is not None:
            self.location_description = location_description
        self.ancillary_info_type = ancillary_info_type
        self.ancillary_info_status = ancillary_info_status
        self.ancillary_info_type_string = ancillary_info_type_string
        self.ancillary_info_status_string = ancillary_info_status_string
        self.date_created = date_created
        if date_removed is not None:
            self.date_removed = date_removed
        self.ancillary_info_description = ancillary_info_description
        if ancillary_info_removal_reason is not None:
            self.ancillary_info_removal_reason = ancillary_info_removal_reason
        self.ancillary_info_coordinates = ancillary_info_coordinates
        self.usrns = usrns

    @property
    def ancillary_info_reference_number(self):
        """Gets the ancillary_info_reference_number of this AncillaryInfoResponse.  # noqa: E501


        :return: The ancillary_info_reference_number of this AncillaryInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._ancillary_info_reference_number

    @ancillary_info_reference_number.setter
    def ancillary_info_reference_number(self, ancillary_info_reference_number):
        """Sets the ancillary_info_reference_number of this AncillaryInfoResponse.


        :param ancillary_info_reference_number: The ancillary_info_reference_number of this AncillaryInfoResponse.  # noqa: E501
        :type: str
        """
        if ancillary_info_reference_number is None:
            raise ValueError("Invalid value for `ancillary_info_reference_number`, must not be `None`")  # noqa: E501

        self._ancillary_info_reference_number = ancillary_info_reference_number

    @property
    def location_description(self):
        """Gets the location_description of this AncillaryInfoResponse.  # noqa: E501


        :return: The location_description of this AncillaryInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._location_description

    @location_description.setter
    def location_description(self, location_description):
        """Sets the location_description of this AncillaryInfoResponse.


        :param location_description: The location_description of this AncillaryInfoResponse.  # noqa: E501
        :type: str
        """

        self._location_description = location_description

    @property
    def ancillary_info_type(self):
        """Gets the ancillary_info_type of this AncillaryInfoResponse.  # noqa: E501


        :return: The ancillary_info_type of this AncillaryInfoResponse.  # noqa: E501
        :rtype: AncillaryInfoTypeResponse
        """
        return self._ancillary_info_type

    @ancillary_info_type.setter
    def ancillary_info_type(self, ancillary_info_type):
        """Sets the ancillary_info_type of this AncillaryInfoResponse.


        :param ancillary_info_type: The ancillary_info_type of this AncillaryInfoResponse.  # noqa: E501
        :type: AncillaryInfoTypeResponse
        """
        if ancillary_info_type is None:
            raise ValueError("Invalid value for `ancillary_info_type`, must not be `None`")  # noqa: E501

        self._ancillary_info_type = ancillary_info_type

    @property
    def ancillary_info_status(self):
        """Gets the ancillary_info_status of this AncillaryInfoResponse.  # noqa: E501


        :return: The ancillary_info_status of this AncillaryInfoResponse.  # noqa: E501
        :rtype: AncillaryInfoStatusResponse
        """
        return self._ancillary_info_status

    @ancillary_info_status.setter
    def ancillary_info_status(self, ancillary_info_status):
        """Sets the ancillary_info_status of this AncillaryInfoResponse.


        :param ancillary_info_status: The ancillary_info_status of this AncillaryInfoResponse.  # noqa: E501
        :type: AncillaryInfoStatusResponse
        """
        if ancillary_info_status is None:
            raise ValueError("Invalid value for `ancillary_info_status`, must not be `None`")  # noqa: E501

        self._ancillary_info_status = ancillary_info_status

    @property
    def ancillary_info_type_string(self):
        """Gets the ancillary_info_type_string of this AncillaryInfoResponse.  # noqa: E501


        :return: The ancillary_info_type_string of this AncillaryInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._ancillary_info_type_string

    @ancillary_info_type_string.setter
    def ancillary_info_type_string(self, ancillary_info_type_string):
        """Sets the ancillary_info_type_string of this AncillaryInfoResponse.


        :param ancillary_info_type_string: The ancillary_info_type_string of this AncillaryInfoResponse.  # noqa: E501
        :type: str
        """
        if ancillary_info_type_string is None:
            raise ValueError("Invalid value for `ancillary_info_type_string`, must not be `None`")  # noqa: E501

        self._ancillary_info_type_string = ancillary_info_type_string

    @property
    def ancillary_info_status_string(self):
        """Gets the ancillary_info_status_string of this AncillaryInfoResponse.  # noqa: E501


        :return: The ancillary_info_status_string of this AncillaryInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._ancillary_info_status_string

    @ancillary_info_status_string.setter
    def ancillary_info_status_string(self, ancillary_info_status_string):
        """Sets the ancillary_info_status_string of this AncillaryInfoResponse.


        :param ancillary_info_status_string: The ancillary_info_status_string of this AncillaryInfoResponse.  # noqa: E501
        :type: str
        """
        if ancillary_info_status_string is None:
            raise ValueError("Invalid value for `ancillary_info_status_string`, must not be `None`")  # noqa: E501

        self._ancillary_info_status_string = ancillary_info_status_string

    @property
    def date_created(self):
        """Gets the date_created of this AncillaryInfoResponse.  # noqa: E501


        :return: The date_created of this AncillaryInfoResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this AncillaryInfoResponse.


        :param date_created: The date_created of this AncillaryInfoResponse.  # noqa: E501
        :type: datetime
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def date_removed(self):
        """Gets the date_removed of this AncillaryInfoResponse.  # noqa: E501


        :return: The date_removed of this AncillaryInfoResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._date_removed

    @date_removed.setter
    def date_removed(self, date_removed):
        """Sets the date_removed of this AncillaryInfoResponse.


        :param date_removed: The date_removed of this AncillaryInfoResponse.  # noqa: E501
        :type: datetime
        """

        self._date_removed = date_removed

    @property
    def ancillary_info_description(self):
        """Gets the ancillary_info_description of this AncillaryInfoResponse.  # noqa: E501


        :return: The ancillary_info_description of this AncillaryInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._ancillary_info_description

    @ancillary_info_description.setter
    def ancillary_info_description(self, ancillary_info_description):
        """Sets the ancillary_info_description of this AncillaryInfoResponse.


        :param ancillary_info_description: The ancillary_info_description of this AncillaryInfoResponse.  # noqa: E501
        :type: str
        """
        if ancillary_info_description is None:
            raise ValueError("Invalid value for `ancillary_info_description`, must not be `None`")  # noqa: E501

        self._ancillary_info_description = ancillary_info_description

    @property
    def ancillary_info_removal_reason(self):
        """Gets the ancillary_info_removal_reason of this AncillaryInfoResponse.  # noqa: E501


        :return: The ancillary_info_removal_reason of this AncillaryInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._ancillary_info_removal_reason

    @ancillary_info_removal_reason.setter
    def ancillary_info_removal_reason(self, ancillary_info_removal_reason):
        """Sets the ancillary_info_removal_reason of this AncillaryInfoResponse.


        :param ancillary_info_removal_reason: The ancillary_info_removal_reason of this AncillaryInfoResponse.  # noqa: E501
        :type: str
        """

        self._ancillary_info_removal_reason = ancillary_info_removal_reason

    @property
    def ancillary_info_coordinates(self):
        """Gets the ancillary_info_coordinates of this AncillaryInfoResponse.  # noqa: E501


        :return: The ancillary_info_coordinates of this AncillaryInfoResponse.  # noqa: E501
        :rtype: list[object]
        """
        return self._ancillary_info_coordinates

    @ancillary_info_coordinates.setter
    def ancillary_info_coordinates(self, ancillary_info_coordinates):
        """Sets the ancillary_info_coordinates of this AncillaryInfoResponse.


        :param ancillary_info_coordinates: The ancillary_info_coordinates of this AncillaryInfoResponse.  # noqa: E501
        :type: list[object]
        """
        if ancillary_info_coordinates is None:
            raise ValueError("Invalid value for `ancillary_info_coordinates`, must not be `None`")  # noqa: E501

        self._ancillary_info_coordinates = ancillary_info_coordinates

    @property
    def usrns(self):
        """Gets the usrns of this AncillaryInfoResponse.  # noqa: E501


        :return: The usrns of this AncillaryInfoResponse.  # noqa: E501
        :rtype: list[float]
        """
        return self._usrns

    @usrns.setter
    def usrns(self, usrns):
        """Sets the usrns of this AncillaryInfoResponse.


        :param usrns: The usrns of this AncillaryInfoResponse.  # noqa: E501
        :type: list[float]
        """
        if usrns is None:
            raise ValueError("Invalid value for `usrns`, must not be `None`")  # noqa: E501

        self._usrns = usrns

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AncillaryInfoResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AncillaryInfoResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ForwardPlanUpdateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_user_identifier': 'str',
        'internal_user_name': 'str',
        'works_coordinates': 'object',
        'start_date': 'datetime',
        'end_date': 'datetime',
        'works_location_description': 'str',
        'description_of_work': 'str',
        'project_reference_number': 'str',
        'traffic_management_type': 'AllOfForwardPlanUpdateRequestTrafficManagementType',
        'additional_info': 'str',
        'forward_plan_asds': 'list[PermitASD]'
    }

    attribute_map = {
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name',
        'works_coordinates': 'works_coordinates',
        'start_date': 'start_date',
        'end_date': 'end_date',
        'works_location_description': 'works_location_description',
        'description_of_work': 'description_of_work',
        'project_reference_number': 'project_reference_number',
        'traffic_management_type': 'traffic_management_type',
        'additional_info': 'additional_info',
        'forward_plan_asds': 'forward_plan_asds'
    }

    def __init__(self, internal_user_identifier=None, internal_user_name=None, works_coordinates=None, start_date=None, end_date=None, works_location_description=None, description_of_work=None, project_reference_number=None, traffic_management_type=None, additional_info=None, forward_plan_asds=None):  # noqa: E501
        """ForwardPlanUpdateRequest - a model defined in Swagger"""  # noqa: E501
        self._internal_user_identifier = None
        self._internal_user_name = None
        self._works_coordinates = None
        self._start_date = None
        self._end_date = None
        self._works_location_description = None
        self._description_of_work = None
        self._project_reference_number = None
        self._traffic_management_type = None
        self._additional_info = None
        self._forward_plan_asds = None
        self.discriminator = None
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name
        self.works_coordinates = works_coordinates
        self.start_date = start_date
        self.end_date = end_date
        self.works_location_description = works_location_description
        self.description_of_work = description_of_work
        if project_reference_number is not None:
            self.project_reference_number = project_reference_number
        if traffic_management_type is not None:
            self.traffic_management_type = traffic_management_type
        if additional_info is not None:
            self.additional_info = additional_info
        if forward_plan_asds is not None:
            self.forward_plan_asds = forward_plan_asds

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this ForwardPlanUpdateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_identifier of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this ForwardPlanUpdateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_identifier: The internal_user_identifier of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this ForwardPlanUpdateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_name of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this ForwardPlanUpdateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_name: The internal_user_name of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    @property
    def works_coordinates(self):
        """Gets the works_coordinates of this ForwardPlanUpdateRequest.  # noqa: E501

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point, line string or polygon  # noqa: E501

        :return: The works_coordinates of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: object
        """
        return self._works_coordinates

    @works_coordinates.setter
    def works_coordinates(self, works_coordinates):
        """Sets the works_coordinates of this ForwardPlanUpdateRequest.

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point, line string or polygon  # noqa: E501

        :param works_coordinates: The works_coordinates of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: object
        """
        if works_coordinates is None:
            raise ValueError("Invalid value for `works_coordinates`, must not be `None`")  # noqa: E501

        self._works_coordinates = works_coordinates

    @property
    def start_date(self):
        """Gets the start_date of this ForwardPlanUpdateRequest.  # noqa: E501


        :return: The start_date of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this ForwardPlanUpdateRequest.


        :param start_date: The start_date of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: datetime
        """
        if start_date is None:
            raise ValueError("Invalid value for `start_date`, must not be `None`")  # noqa: E501

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this ForwardPlanUpdateRequest.  # noqa: E501

        end_date must be on or after start_date  # noqa: E501

        :return: The end_date of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this ForwardPlanUpdateRequest.

        end_date must be on or after start_date  # noqa: E501

        :param end_date: The end_date of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: datetime
        """
        if end_date is None:
            raise ValueError("Invalid value for `end_date`, must not be `None`")  # noqa: E501

        self._end_date = end_date

    @property
    def works_location_description(self):
        """Gets the works_location_description of this ForwardPlanUpdateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The works_location_description of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._works_location_description

    @works_location_description.setter
    def works_location_description(self, works_location_description):
        """Sets the works_location_description of this ForwardPlanUpdateRequest.

        Max length 500 characters  # noqa: E501

        :param works_location_description: The works_location_description of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: str
        """
        if works_location_description is None:
            raise ValueError("Invalid value for `works_location_description`, must not be `None`")  # noqa: E501

        self._works_location_description = works_location_description

    @property
    def description_of_work(self):
        """Gets the description_of_work of this ForwardPlanUpdateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The description_of_work of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description_of_work

    @description_of_work.setter
    def description_of_work(self, description_of_work):
        """Sets the description_of_work of this ForwardPlanUpdateRequest.

        Max length 500 characters  # noqa: E501

        :param description_of_work: The description_of_work of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: str
        """
        if description_of_work is None:
            raise ValueError("Invalid value for `description_of_work`, must not be `None`")  # noqa: E501

        self._description_of_work = description_of_work

    @property
    def project_reference_number(self):
        """Gets the project_reference_number of this ForwardPlanUpdateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The project_reference_number of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._project_reference_number

    @project_reference_number.setter
    def project_reference_number(self, project_reference_number):
        """Sets the project_reference_number of this ForwardPlanUpdateRequest.

        Max length 100 characters  # noqa: E501

        :param project_reference_number: The project_reference_number of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: str
        """

        self._project_reference_number = project_reference_number

    @property
    def traffic_management_type(self):
        """Gets the traffic_management_type of this ForwardPlanUpdateRequest.  # noqa: E501


        :return: The traffic_management_type of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: AllOfForwardPlanUpdateRequestTrafficManagementType
        """
        return self._traffic_management_type

    @traffic_management_type.setter
    def traffic_management_type(self, traffic_management_type):
        """Sets the traffic_management_type of this ForwardPlanUpdateRequest.


        :param traffic_management_type: The traffic_management_type of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: AllOfForwardPlanUpdateRequestTrafficManagementType
        """

        self._traffic_management_type = traffic_management_type

    @property
    def additional_info(self):
        """Gets the additional_info of this ForwardPlanUpdateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The additional_info of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._additional_info

    @additional_info.setter
    def additional_info(self, additional_info):
        """Sets the additional_info of this ForwardPlanUpdateRequest.

        Max length 500 characters  # noqa: E501

        :param additional_info: The additional_info of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: str
        """

        self._additional_info = additional_info

    @property
    def forward_plan_asds(self):
        """Gets the forward_plan_asds of this ForwardPlanUpdateRequest.  # noqa: E501


        :return: The forward_plan_asds of this ForwardPlanUpdateRequest.  # noqa: E501
        :rtype: list[PermitASD]
        """
        return self._forward_plan_asds

    @forward_plan_asds.setter
    def forward_plan_asds(self, forward_plan_asds):
        """Sets the forward_plan_asds of this ForwardPlanUpdateRequest.


        :param forward_plan_asds: The forward_plan_asds of this ForwardPlanUpdateRequest.  # noqa: E501
        :type: list[PermitASD]
        """

        self._forward_plan_asds = forward_plan_asds

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ForwardPlanUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ForwardPlanUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#!/usr/bin/env python3
"""
Script to fix swagger client imports by converting absolute imports to relative imports.
This script will:
1. Find all Python files in the swagger_client directory
2. Convert all 'from swagger_client.' imports to 'from .'
3. Collapse any double occurrences of '.api.api.' to '.api.' and '.models.models.' to '.models.'
4. Replace any remaining absolute imports (e.g., 'from swagger_client.models.activity_feature import ...') with relative imports (e.g., 'from .models.activity_feature import ...')
5. Preserve the rest of the file content
"""

import re
from pathlib import Path
import glob

def convert_imports(file_path):
    """Convert absolute imports to relative imports in a file."""
    with open(file_path, 'r', encoding='utf-8') as f:
        content = f.read()

    # Replace all 'from swagger_client.' with 'from .'
    content = re.sub(r'from swagger_client\.', 'from .', content)

    # Collapse any double occurrences of '.api.api.' to '.api.' and '.models.models.' to '.models.'
    content = re.sub(r'\.api\.api\.', '.api.', content)
    content = re.sub(r'\.models\.models\.', '.models.', content)

    # Replace any remaining absolute imports (e.g., 'from swagger_client.models.activity_feature import ...') with relative imports (e.g., 'from .models.activity_feature import ...')
    content = re.sub(r'from swagger_client\.models\.(\w+) import (\w+)', r'from .models.\1 import \2', content)

    with open(file_path, 'w', encoding='utf-8') as f:
        f.write(content)

def main():
    base_dir = Path('src/streetmanager')
    swagger_dirs = glob.glob(str(base_dir / '*/swagger_client'))
    print(f"Found swagger directories: {swagger_dirs}")
    for swagger_dir in swagger_dirs:
        swagger_path = Path(swagger_dir)
        python_files = list(swagger_path.rglob('*.py'))
        print(f"Found Python files in {swagger_path}: {python_files}")
        for file_path in python_files:
            print(f"Processing {file_path}")
            convert_imports(file_path)
            print(f"Completed {file_path}")

if __name__ == '__main__':
    main() 


#!/usr/bin/env python3
"""
Script to fix swagger client imports by converting absolute imports to relative imports.
This script will:
1. Find all Python files in the swagger_client directory
2. Convert absolute imports to relative imports
3. Preserve the rest of the file content
"""

import os
import re
from pathlib import Path

def convert_imports(file_path):
    """Convert absolute imports to relative imports in a file."""
    # Read the file content
    with open(file_path, 'r', encoding='utf-8') as f:
        content = f.read()

    # Pattern to match absolute imports from swagger_client
    pattern = r'from swagger_client\.(.*?) import'
    
    # Function to convert absolute import to relative
    def replace_import(match):
        module_path = match.group(1)
        # Count the number of dots needed based on the file's depth
        depth = len(Path(file_path).relative_to('src/streetmanager/work/swagger_client').parts) - 1
        dots = '.' * depth
        return f'from {dots}models.{module_path} import'

    # Replace all absolute imports with relative ones
    new_content = re.sub(pattern, replace_import, content)
    
    # Write the modified content back to the file
    with open(file_path, 'w', encoding='utf-8') as f:
        f.write(new_content)

def main():
    """Main function to process all Python files in the swagger_client directory."""
    # Get the base directory for swagger_client
    base_dir = Path('src/streetmanager/work/swagger_client')
    
    # Find all Python files in the swagger_client directory
    python_files = list(base_dir.rglob('*.py'))
    
    # Process each file
    for file_path in python_files:
        print(f"Processing {file_path}")
        convert_imports(file_path)
        print(f"Completed {file_path}")

if __name__ == '__main__':
    main() 


# coding: utf-8

"""
    Street Manager Street Lookup API

    See API specification Resource Guide > Street Lookup API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class StreetSummaryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'street_descriptor': 'str',
        'area': 'str',
        'town': 'str',
        'usrn': 'float',
        'administrative_area': 'str',
        'street_centre_point': 'GeoJSONCentrePoint'
    }

    attribute_map = {
        'street_descriptor': 'street_descriptor',
        'area': 'area',
        'town': 'town',
        'usrn': 'usrn',
        'administrative_area': 'administrative_area',
        'street_centre_point': 'street_centre_point'
    }

    def __init__(self, street_descriptor=None, area=None, town=None, usrn=None, administrative_area=None, street_centre_point=None):  # noqa: E501
        """StreetSummaryResponse - a model defined in Swagger"""  # noqa: E501
        self._street_descriptor = None
        self._area = None
        self._town = None
        self._usrn = None
        self._administrative_area = None
        self._street_centre_point = None
        self.discriminator = None
        self.street_descriptor = street_descriptor
        self.area = area
        self.town = town
        self.usrn = usrn
        self.administrative_area = administrative_area
        self.street_centre_point = street_centre_point

    @property
    def street_descriptor(self):
        """Gets the street_descriptor of this StreetSummaryResponse.  # noqa: E501


        :return: The street_descriptor of this StreetSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._street_descriptor

    @street_descriptor.setter
    def street_descriptor(self, street_descriptor):
        """Sets the street_descriptor of this StreetSummaryResponse.


        :param street_descriptor: The street_descriptor of this StreetSummaryResponse.  # noqa: E501
        :type: str
        """
        if street_descriptor is None:
            raise ValueError("Invalid value for `street_descriptor`, must not be `None`")  # noqa: E501

        self._street_descriptor = street_descriptor

    @property
    def area(self):
        """Gets the area of this StreetSummaryResponse.  # noqa: E501


        :return: The area of this StreetSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._area

    @area.setter
    def area(self, area):
        """Sets the area of this StreetSummaryResponse.


        :param area: The area of this StreetSummaryResponse.  # noqa: E501
        :type: str
        """
        if area is None:
            raise ValueError("Invalid value for `area`, must not be `None`")  # noqa: E501

        self._area = area

    @property
    def town(self):
        """Gets the town of this StreetSummaryResponse.  # noqa: E501


        :return: The town of this StreetSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._town

    @town.setter
    def town(self, town):
        """Sets the town of this StreetSummaryResponse.


        :param town: The town of this StreetSummaryResponse.  # noqa: E501
        :type: str
        """
        if town is None:
            raise ValueError("Invalid value for `town`, must not be `None`")  # noqa: E501

        self._town = town

    @property
    def usrn(self):
        """Gets the usrn of this StreetSummaryResponse.  # noqa: E501


        :return: The usrn of this StreetSummaryResponse.  # noqa: E501
        :rtype: float
        """
        return self._usrn

    @usrn.setter
    def usrn(self, usrn):
        """Sets the usrn of this StreetSummaryResponse.


        :param usrn: The usrn of this StreetSummaryResponse.  # noqa: E501
        :type: float
        """
        if usrn is None:
            raise ValueError("Invalid value for `usrn`, must not be `None`")  # noqa: E501

        self._usrn = usrn

    @property
    def administrative_area(self):
        """Gets the administrative_area of this StreetSummaryResponse.  # noqa: E501


        :return: The administrative_area of this StreetSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._administrative_area

    @administrative_area.setter
    def administrative_area(self, administrative_area):
        """Sets the administrative_area of this StreetSummaryResponse.


        :param administrative_area: The administrative_area of this StreetSummaryResponse.  # noqa: E501
        :type: str
        """
        if administrative_area is None:
            raise ValueError("Invalid value for `administrative_area`, must not be `None`")  # noqa: E501

        self._administrative_area = administrative_area

    @property
    def street_centre_point(self):
        """Gets the street_centre_point of this StreetSummaryResponse.  # noqa: E501


        :return: The street_centre_point of this StreetSummaryResponse.  # noqa: E501
        :rtype: GeoJSONCentrePoint
        """
        return self._street_centre_point

    @street_centre_point.setter
    def street_centre_point(self, street_centre_point):
        """Sets the street_centre_point of this StreetSummaryResponse.


        :param street_centre_point: The street_centre_point of this StreetSummaryResponse.  # noqa: E501
        :type: GeoJSONCentrePoint
        """
        if street_centre_point is None:
            raise ValueError("Invalid value for `street_centre_point`, must not be `None`")  # noqa: E501

        self._street_centre_point = street_centre_point

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StreetSummaryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreetSummaryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#!/usr/bin/env python3
"""
Script to fix swagger client imports by converting absolute imports to relative imports.
This script will:
1. Find all Python files in the swagger_client directory
2. Convert all 'from swagger_client.' imports to 'from .'
3. Collapse any double occurrences of '.api.api.default_api' to '.api.default_api' and '.models.models.' to '.models.'
4. Replace any remaining absolute imports (e.g., 'from swagger_client.models.activity_feature import ...') with relative imports (e.g., 'from .models.activity_feature import ...')
5. Preserve the rest of the file content
"""

import re
from pathlib import Path
import glob

def convert_imports(file_path):
    """Convert absolute imports to relative imports in a file."""
    with open(file_path, 'r', encoding='utf-8') as f:
        content = f.read()

    # Replace all 'from swagger_client.' with 'from .'
    content = re.sub(r'from swagger_client\.', 'from .', content)

    # Handle 'import swagger_client.models' and 'from swagger_client import rest'
    content = re.sub(r'import swagger_client\.models', 'import .models', content)
    content = re.sub(r'from swagger_client import rest', 'from . import rest', content)

    # Rule for swagger_client/__init__.py: if it has an incorrect direct import of DefaultApi, point it to .api
    original_line_pattern_for_debug = r'(# import apis into sdk package\\s*\\n\\s*)from \\.default_api import DefaultApi'
    replacement_pattern_for_debug = r'\\1from .api import DefaultApi'
    
    if "swagger_client/__init__.py" in str(file_path):
        if re.search(original_line_pattern_for_debug, content):
            print(f"DEBUG: Found pattern for swagger_client/__init__.py DefaultApi import in {file_path}")
        else:
            print(f"DEBUG: DID NOT find pattern for swagger_client/__init__.py DefaultApi import in {file_path}")
            # Log a snippet of the content around where we expect the import
            try:
                idx = content.index("# import apis into sdk package")
                print(f"DEBUG: Content snippet around '# import apis into sdk package':\\n{content[max(0, idx-30):idx+100]}")
            except ValueError:
                print("DEBUG: '# import apis into sdk package' not even found.")


    content_before_sdk_fix = content
    content = re.sub(original_line_pattern_for_debug, replacement_pattern_for_debug, content)
    if "swagger_client/__init__.py" in str(file_path) and content_before_sdk_fix != content:
        print(f"DEBUG: Applied swagger_client/__init__.py DefaultApi import fix in {file_path}")
    elif "swagger_client/__init__.py" in str(file_path) and content_before_sdk_fix == content and re.search(r'from \\.api import DefaultApi', content_before_sdk_fix) is None : # only print if not already correct
        print(f"DEBUG: swagger_client/__init__.py DefaultApi import fix DID NOT change content in {file_path}")

    # Correct common problematic import pattern for DefaultApi in api/__init__.py
    content = re.sub(r'from \.api\.default_api import DefaultApi', 'from .default_api import DefaultApi', content)

    # Correct common problematic import pattern for DefaultApi in swagger_client/__init__.py
    content = re.sub(r'# import apis into sdk package\nfrom \.api\.default_api import DefaultApi', '# import apis into sdk package\nfrom .api import DefaultApi', content)

    # Collapse any double occurrences of '.api.api.default_api' to '.api.default_api' and '.models.models.' to '.models.'
    content = re.sub(r'\.api\.api\.default_api', '.api.default_api', content)
    content = re.sub(r'\.models\.models\.', '.models.', content)

    # Replace any remaining absolute imports (e.g., 'from swagger_client.models.activity_feature import ...') with relative imports (e.g., 'from .models.activity_feature import ...')
    # This specific rule is removed for now to isolate the problem
    # content = re.sub(r'from swagger_client\.models\.(\w+) import (\w+)', r'from .models.\1 import \2', content)

    with open(file_path, 'w', encoding='utf-8') as f:
        f.write(content)

def main():
    base_dir = Path('src/streetmanager')
    swagger_dirs = glob.glob(str(base_dir / '*/swagger_client'))
    print(f"Found swagger directories: {swagger_dirs}")
    for swagger_dir in swagger_dirs:
        swagger_path = Path(swagger_dir)
        python_files = list(swagger_path.rglob('*.py'))
        print(f"Found Python files in {swagger_path}: {python_files}")
        for file_path in python_files:
            print(f"Processing {file_path}")
            convert_imports(file_path)
            print(f"Completed {file_path}")

if __name__ == '__main__':
    main() 